package it.unibo.tw0708.web;

import java.io.PrintWriter;

public class HtmlPrintWriter {

	// --- Constants ---------
	
	/**
	 * The string 'html'
	 */
	public static final String HTML = "html";

	/**
	 * The string 'head'
	 */
	public static final String HEAD = "head";
	
	/**
	 * The string 'body'
	 */
	public static final String BODY = "body";

	// --- Private members -----------
	
	/**
	 * The print writer of the HTTP response to write to
	 */
	private PrintWriter out;

	// --- Constructor ------------
	
	/**
	 * Constructor
	 * @param the response output writer
	 */
	public HtmlPrintWriter(PrintWriter out) {
		this.out = out;
	}

	// --- public methods --------------------

	public void open(String tagName, HtmlAttribute[] attributes) {
		this.out.println(HtmlPrintWriter._open(tagName,attributes));
	}

	public void close(String tagName) {
		this.out.println(HtmlPrintWriter._close(tagName));
	}

	public void element(String tagName, HtmlAttribute[] attributes, String content) {
		this.out.println(HtmlPrintWriter._element(tagName,attributes,content));
	}

	public PrintWriter getWriter() {
		return this.out;
	}

	// --- static methods ----------------------------
	
	public static String _open(String tagName, HtmlAttribute[] attributes) {
		if ( tagName == null || tagName.equals("") )
			return "";
		String result = "<"+ tagName;
		if ( attributes != null ) {
			for ( HtmlAttribute attribute : attributes ) {
				if ( attribute != null ) {
					result += attribute.toString();
				}
			}
		}
		result += ">\n";
		return result;
	}
	
	public static String _close(String tagName) {
		if ( tagName == null || tagName.equals("") )
			return "";
		return "</"+ tagName + ">\n";
	}

	public static String _element(String tagName, HtmlAttribute[] attributes, String content) {
		String result = _open(tagName, attributes);
		if ( content != null )
			result += content;
		result += _close(tagName);
		return result;
	}

	// ----------------------------------------------------------

	/**
	 * A inner class to handle attributes
	 */
	public class HtmlAttribute {
		// --- Members --------------
		private String name;
		private String value;
		// --- Constructor --------------
		public HtmlAttribute(String name, String value) {
			this.name = name;
			this.value = value;
		}
		// --- Methods ----------------------
		@Override
		public String toString() {
			if ( name == null || name.equals("") )
				return " ";
			else
				return " " + this.name + "=\"" + this.value + "\""; 
		}
	}
}
